@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2013 Shintaro Fujiwara 
+ * Copyright (C) 2007-2014 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 //Added by qt3to4:
 #include <Q3VBoxLayout>
 #include <Q3HBoxLayout>
+#include <QLabel>
 //#####################
 #include <unistd.h>
 #include <sys/types.h>
@@ -41,24 +42,26 @@
 //default constructor
 SegatexYum::SegatexYum(QWidget *parent, const char *name): QDialog(parent, name)
 {
+
 		setCaption(tr("Yum SELinux"));
-		targetedCheckBox = new QCheckBox(tr("policy-targeted"), this);
-		minimalCheckBox = new QCheckBox(tr("policy-minimal"), this);
-		mlsCheckBox = new QCheckBox(tr("policy-mls"), this);
-		targetedCheckBox->setChecked(true);
-		minimalCheckBox->setChecked(true);
-		mlsCheckBox->setChecked(true);
+		//targetedCheckBox = new QCheckBox(tr("policy-targeted"), this);
+		//minimumCheckBox = new QCheckBox(tr("policy-minimum"), this);
+		//mlsCheckBox = new QCheckBox(tr("policy-mls"), this);
+		//targetedCheckBox->setChecked(true);
+		//minimalCheckBox->setChecked(true);
+		//mlsCheckBox->setChecked(true);
 		yumButton = new QPushButton(tr("&Install/Update"), this);
 		closeButton = new QPushButton(tr("&Close"), this);
 		yumButton->setDefault(true);
+                //////////////packagesLabel = new QLabel(tr("Packages"),this);
 
 		connect(yumButton, SIGNAL(clicked()), this, SLOT(yum_clicked()));
 		connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 
-		Q3VBoxLayout *leftLayout = new Q3VBoxLayout;
-		leftLayout->addWidget(targetedCheckBox);
-		leftLayout->addWidget(minimalCheckBox);
-		leftLayout->addWidget(mlsCheckBox);
+		//Q3VBoxLayout *leftLayout = new Q3VBoxLayout;
+		//leftLayout->addWidget(targetedCheckBox);
+		//leftLayout->addWidget(minimalCheckBox);
+		//leftLayout->addWidget(mlsCheckBox);
 
 		Q3VBoxLayout *rightLayout = new Q3VBoxLayout;
 		rightLayout->addWidget(yumButton);
@@ -68,7 +71,7 @@ SegatexYum::SegatexYum(QWidget *parent, const char *name): QDialog(parent, name)
 		Q3HBoxLayout *mainLayout = new Q3HBoxLayout(this);
 		mainLayout->setMargin(11);
 		mainLayout->setSpacing(6);
-		mainLayout->addLayout(leftLayout);
+		//mainLayout->addLayout(leftLayout);
 		mainLayout->addLayout(rightLayout);
 		//needs here to be declared
 		selinux_yum_process = 0;
