@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2013 Shintaro Fujiwara 
+ * Copyright (C) 2007-2014 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -122,23 +122,24 @@ void SegatexYumProcess::yum_install_base_process()
 	process->addArgument("-y");
 	process->addArgument("install");
 	process->addArgument("audit");
-	process->addArgument("selinux-policy");
-	process->addArgument("selinux-policy-devel");
-	process->addArgument("selinux-policy-targeted");
-	process->addArgument("selinux-policy-minimal");
-	process->addArgument("selinux-policy-mls");
-	process->addArgument("selinux-doc");
+	process->addArgument("checkpolicy");
 	process->addArgument("libsepol");
 	process->addArgument("libselinux");
 	process->addArgument("libselinux-devel");
 	process->addArgument("libselinux-python");
 	process->addArgument("libsemanage");
-	process->addArgument("policycoreutils");
-	process->addArgument("checkpolicy");
-	process->addArgument("seedit*");
-	process->addArgument("xguest");
-	process->addArgument("sepostgresql");
 	process->addArgument("mod_selinux");
+	process->addArgument("policycoreutils");
+	process->addArgument("selinux-doc");
+	process->addArgument("selinux-policy");
+	process->addArgument("selinux-policy-devel");
+	process->addArgument("selinux-policy-minimum");
+	process->addArgument("selinux-policy-mls");
+	process->addArgument("selinux-policy-sandbox");
+	process->addArgument("selinux-policy-targeted");
+	process->addArgument("sepolgen");
+	process->addArgument("setools-console");
+	process->addArgument("xguest");
 	connect(process, SIGNAL(readyReadStdout()),this,SLOT(readFromStdout()));
 	connect(process, SIGNAL(readyReadStderr()),this,SLOT(updateOutputTextEdit()));
 	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
@@ -152,23 +153,24 @@ void SegatexYumProcess::yum_update_base_process()
 	process1->addArgument("-y");
 	process1->addArgument("update");
 	process1->addArgument("audit");
-	process1->addArgument("selinux-policy");
-	process1->addArgument("selinux-policy-devel");
-	process1->addArgument("selinux-policy-targeted");
-	process1->addArgument("selinux-policy-minimal");
-	process1->addArgument("selinux-policy-mls");
-	process1->addArgument("selinux-doc");
+	process1->addArgument("checkpolicy");
 	process1->addArgument("libsepol");
 	process1->addArgument("libselinux");
 	process1->addArgument("libselinux-devel");
 	process1->addArgument("libselinux-python");
 	process1->addArgument("libsemanage");
-	process1->addArgument("policycoreutils");
-	process1->addArgument("checkpolicy");
-	process1->addArgument("seedit*");
-	process1->addArgument("xguest");
-	process1->addArgument("sepostgresql");
 	process1->addArgument("mod_selinux");
+	process1->addArgument("policycoreutils");
+	process1->addArgument("selinux-doc");
+	process1->addArgument("selinux-policy");
+	process1->addArgument("selinux-policy-devel");
+	process1->addArgument("selinux-policy-minimum");
+	process1->addArgument("selinux-policy-mls");
+	process1->addArgument("selinux-policy-sandbox");
+	process1->addArgument("selinux-policy-targeted");
+	process1->addArgument("sepolgen");
+	process1->addArgument("setools-console");
+	process1->addArgument("xguest");
 	connect(process1, SIGNAL(readyReadStdout()),this,SLOT(readFromStdout1()));
 	connect(process1, SIGNAL(readyReadStderr()),this,SLOT(updateOutputTextEdit1()));
 	connect(process1, SIGNAL(processExited()),this,SLOT(processExited1()));
